@@ -50,11 +50,11 @@ setup (Test *test, gconstpointer unused)
 	/* Successful load */
 	test->module = gck_module_initialize (_GCK_TEST_MODULE_PATH, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_MODULE (test->module));
+	g_assert_true (GCK_IS_MODULE (test->module));
 	g_object_add_weak_pointer (G_OBJECT (test->module), (gpointer *)&test->module);
 
 	slots = gck_module_get_slots (test->module, TRUE);
-	g_assert (slots != NULL);
+	g_assert_nonnull (slots);
 
 	test->slot = GCK_SLOT (slots->data);
 	g_object_ref (test->slot);
@@ -63,7 +63,7 @@ setup (Test *test, gconstpointer unused)
 
 	test->session = gck_slot_open_session (test->slot, 0, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (test->session));
+	g_assert_true (GCK_IS_SESSION (test->session));
 	g_object_add_weak_pointer (G_OBJECT (test->session), (gpointer *)&test->session);
 }
 
@@ -74,9 +74,11 @@ teardown (Test *test, gconstpointer unused)
 	g_object_unref (test->slot);
 	g_object_unref (test->module);
 
-	g_assert (test->session == NULL);
-	g_assert (test->slot == NULL);
-	g_assert (test->module == NULL);
+	egg_test_wait_for_gtask_thread (test->session || test->slot || test->module);
+
+	g_assert_null (test->session);
+	g_assert_null (test->slot);
+	g_assert_null (test->module);
 }
 
 static void
@@ -87,13 +89,13 @@ test_session_props (Test *test, gconstpointer unused)
 	gulong handle;
 
 	g_object_get (test->session, "module", &mod, "handle", &handle, "slot", &sl, NULL);
-	g_assert (mod == test->module);
-	g_assert (sl == test->slot);
+	g_assert_true (mod == test->module);
+	g_assert_true (sl == test->slot);
 	g_object_unref (mod);
 	g_object_unref (sl);
 
-	g_assert (handle != 0);
-	g_assert (gck_session_get_handle (test->session) == handle);
+	g_assert_cmpuint (handle, !=, 0);
+	g_assert_cmpuint (gck_session_get_handle (test->session), ==, handle);
 }
 
 static void
@@ -102,11 +104,11 @@ test_session_info (Test *test, gconstpointer unused)
 	GckSessionInfo *info;
 
 	info = gck_session_get_info (test->session);
-	g_assert (info != NULL && "no session info");
+	g_assert_nonnull (info);
 
-	g_assert (info->slot_id == gck_slot_get_handle (test->slot));
-	g_assert ((info->flags & CKF_SERIAL_SESSION) == CKF_SERIAL_SESSION);
-	g_assert (info->device_error == 1414);
+	g_assert_cmpuint (info->slot_id, ==, gck_slot_get_handle (test->slot));
+	g_assert_cmphex ((info->flags & CKF_SERIAL_SESSION), ==, CKF_SERIAL_SESSION);
+	g_assert_cmpuint (info->device_error, ==, 1414);
 	gck_session_info_free (info);
 }
 
@@ -127,7 +129,7 @@ test_open_close_session (Test *test, gconstpointer unused)
 
 	sess = gck_slot_open_session (test->slot, 0, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (sess));
+	g_assert_true (GCK_IS_SESSION (sess));
 
 	g_object_unref (sess);
 
@@ -135,20 +137,21 @@ test_open_close_session (Test *test, gconstpointer unused)
 	gck_slot_open_session_async (test->slot, 0, NULL, fetch_async_result, &result);
 
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 
 	/* Get the result */
 	g_object_add_weak_pointer (G_OBJECT (result), (gpointer *)&result);
 	sess = gck_slot_open_session_finish (test->slot, result, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (sess));
+	g_assert_true (GCK_IS_SESSION (sess));
 	g_object_add_weak_pointer (G_OBJECT (sess), (gpointer *)&sess);
 
 	g_object_unref (result);
-	g_assert (result == NULL);
+	g_assert_null (result);
 
 	g_object_unref (sess);
-	g_assert (sess == NULL);
+	egg_test_wait_for_gtask_thread (sess);
+	g_assert_null (sess);
 }
 
 static void
@@ -161,7 +164,7 @@ test_session_initable (Test *test,
 
 	sess = gck_session_open (test->slot, 0, NULL, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (sess));
+	g_assert_true (GCK_IS_SESSION (sess));
 
 	g_object_unref (sess);
 
@@ -169,12 +172,12 @@ test_session_initable (Test *test,
 	gck_session_open_async (test->slot, 0, NULL, NULL, fetch_async_result, &result);
 
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 
 	/* Get the result */
 	sess = gck_session_open_finish (result, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (sess));
+	g_assert_true (GCK_IS_SESSION (sess));
 
 	g_object_unref (result);
 	g_object_unref (sess);
@@ -193,12 +196,12 @@ test_session_already (Test *test,
 	CK_RV rv;
 
 	funcs = gck_module_get_functions (test->module);
-	g_assert (funcs != NULL);
+	g_assert_nonnull (funcs);
 
 	rv = funcs->C_OpenSession (gck_slot_get_handle (test->slot), CKF_SERIAL_SESSION,
 	                           NULL, NULL, &handle);
 	gck_assert_cmprv (rv, ==, CKR_OK);
-	g_assert (handle != 0);
+	g_assert_cmpuint (handle, !=, 0);
 
 	session = g_initable_new (GCK_TYPE_SESSION, NULL, &error,
 	                          "slot", test->slot,
@@ -206,14 +209,14 @@ test_session_already (Test *test,
 	                          NULL);
 
 	g_assert_no_error (error);
-	g_assert (GCK_IS_SESSION (session));
+	g_assert_true (GCK_IS_SESSION (session));
 	gck_assert_cmpulong (handle, ==, gck_session_get_handle (session));
 	g_object_unref (session);
 
 	rv = funcs->C_OpenSession (gck_slot_get_handle (test->slot), CKF_SERIAL_SESSION,
 	                           NULL, NULL, &handle);
 	gck_assert_cmprv (rv, ==, CKR_OK);
-	g_assert (handle != 0);
+	g_assert_cmpuint (handle, !=, 0);
 
 	/* Test opening async */
 	g_async_initable_new_async (GCK_TYPE_SESSION, G_PRIORITY_DEFAULT, NULL,
@@ -223,14 +226,14 @@ test_session_already (Test *test,
 	                            NULL);
 
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 
 	/* Get the result */
 	source = g_async_result_get_source_object (result);
 	session = GCK_SESSION (g_async_initable_new_finish (G_ASYNC_INITABLE (source), result, &error));
 	g_object_unref (source);
 	g_assert_no_error (error);
-	g_assert (GCK_IS_SESSION (session));
+	g_assert_true (GCK_IS_SESSION (session));
 	gck_assert_cmpulong (handle, ==, gck_session_get_handle (session));
 
 	g_object_unref (result);
@@ -250,7 +253,7 @@ test_open_interaction (Test *test,
 
 	sess = gck_session_open (test->slot, GCK_SESSION_LOGIN_USER, interaction, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (sess));
+	g_assert_true (GCK_IS_SESSION (sess));
 
 	g_object_unref (sess);
 
@@ -258,12 +261,12 @@ test_open_interaction (Test *test,
 	gck_session_open_async (test->slot, GCK_SESSION_LOGIN_USER, interaction, NULL, fetch_async_result, &result);
 
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 
 	/* Get the result */
 	sess = gck_session_open_finish (result, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (sess));
+	g_assert_true (GCK_IS_SESSION (sess));
 
 	g_object_unref (interaction);
 	g_object_unref (result);
@@ -281,30 +284,30 @@ test_init_set_pin (Test *test, gconstpointer unused)
 	/* init pin */
 	ret = gck_session_init_pin (test->session, (guchar*)"booo", 4, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	/* set pin */
 	ret = gck_session_set_pin (test->session, (guchar*)"booo", 4, (guchar*)"tooo", 4, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	/* init pin async */
 	gck_session_init_pin_async (test->session, (guchar*)"booo", 4, NULL, fetch_async_result, &result);
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 	ret = gck_session_init_pin_finish (test->session, result, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 	g_object_unref (result);
 	result = NULL;
 
 	/* set pin async */
 	gck_session_set_pin_async (test->session, (guchar*)"booo", 4, (guchar*)"tooo", 4, NULL, fetch_async_result, &result);
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 	ret = gck_session_set_pin_finish (test->session, result, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 	g_object_unref (result);
 	result = NULL;
 }
@@ -320,14 +323,14 @@ test_login_logout (Test *test, gconstpointer unused)
 	/* login/logout */
 	ret = gck_session_login (test->session, CKU_USER, (guchar*)"booo", 4, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	state = gck_session_get_state (test->session);
 	gck_assert_cmpulong (state, ==, CKS_RO_USER_FUNCTIONS);
 
 	ret = gck_session_logout (test->session, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	state = gck_session_get_state (test->session);
 	gck_assert_cmpulong (state, ==, CKS_RO_PUBLIC_SESSION);
@@ -335,11 +338,11 @@ test_login_logout (Test *test, gconstpointer unused)
 	/* login async */
 	gck_session_login_async (test->session, CKU_USER, (guchar*)"booo", 4, NULL, fetch_async_result, &result);
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 
 	ret = gck_session_login_finish (test->session, result, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	g_object_unref (result);
 	result = NULL;
@@ -350,11 +353,11 @@ test_login_logout (Test *test, gconstpointer unused)
 	/* logout async */
 	gck_session_logout_async (test->session, NULL, fetch_async_result, &result);
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 
 	ret = gck_session_logout_finish (test->session, result, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	state = gck_session_get_state (test->session);
 	gck_assert_cmpulong (state, ==, CKS_RO_PUBLIC_SESSION);
@@ -378,14 +381,14 @@ test_login_interactive (Test *test,
 	/* login/logout */
 	ret = gck_session_login_interactive (test->session, CKU_USER, interaction, NULL, &error);
 	g_assert_no_error (error);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	state = gck_session_get_state (test->session);
 	gck_assert_cmpulong (state, ==, CKS_RO_USER_FUNCTIONS);
 
 	ret = gck_session_logout (test->session, NULL, &error);
 	g_assert_no_error (error);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	state = gck_session_get_state (test->session);
 	gck_assert_cmpulong (state, ==, CKS_RO_PUBLIC_SESSION);
@@ -393,11 +396,11 @@ test_login_interactive (Test *test,
 	/* login async */
 	gck_session_login_interactive_async (test->session, CKU_USER, interaction, NULL, fetch_async_result, &result);
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 
 	ret = gck_session_login_interactive_finish (test->session, result, &error);
 	g_assert_no_error (error);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	g_object_unref (result);
 	result = NULL;
@@ -407,7 +410,7 @@ test_login_interactive (Test *test,
 
 	ret = gck_session_logout (test->session, NULL, &error);
 	g_assert_no_error (error);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	state = gck_session_get_state (test->session);
 	gck_assert_cmpulong (state, ==, CKS_RO_PUBLIC_SESSION);
@@ -418,11 +421,11 @@ test_login_interactive (Test *test,
 static gboolean
 authenticate_token (GckModule *module, GckSlot *slot, gchar *label, gchar **password, gpointer unused)
 {
-	g_assert (unused == GUINT_TO_POINTER (35));
-	g_assert (password != NULL);
-	g_assert (*password == NULL);
-	g_assert (GCK_IS_MODULE (module));
-	g_assert (GCK_IS_SLOT (slot));
+	g_assert_true (unused == GUINT_TO_POINTER (35));
+	g_assert_nonnull (password);
+	g_assert_null (*password);
+	g_assert_true (GCK_IS_MODULE (module));
+	g_assert_true (GCK_IS_SLOT (slot));
 
 	*password = g_strdup ("booo");
 	return TRUE;
@@ -446,52 +449,52 @@ test_auto_login (Test *test, gconstpointer unused)
 
 	/* Try to do something that requires a login */
 	object = gck_session_create_object (test->session, attrs, NULL, &err);
-	g_assert (!object);
-	g_assert (err && err->code == CKR_USER_NOT_LOGGED_IN);
+	g_assert_null (object);
+	g_assert_true (err && err->code == CKR_USER_NOT_LOGGED_IN);
 	g_clear_error (&err);
 
 	/* Setup for auto login */
 	g_signal_connect (test->module, "authenticate-slot", G_CALLBACK (authenticate_token), GUINT_TO_POINTER (35));
 	new_session = gck_slot_open_session (test->slot, GCK_SESSION_READ_WRITE | GCK_SESSION_LOGIN_USER, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (new_session));
+	g_assert_true (GCK_IS_SESSION (new_session));
 
 	/* Try again to do something that requires a login */
 	object = gck_session_create_object (new_session, attrs, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_OBJECT (object));
+	g_assert_true (GCK_IS_OBJECT (object));
 	g_object_unref (object);
 
 	/* We should now be logged in, try to log out */
 	ret = gck_session_logout (new_session, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	g_object_unref (new_session);
 
 	/* Now try the same thing, but asyncronously */
 	gck_slot_open_session_async (test->slot, GCK_SESSION_READ_WRITE | GCK_SESSION_LOGIN_USER, NULL, fetch_async_result, &result);
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 	new_session = gck_slot_open_session_finish (test->slot, result, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_SESSION (new_session));
+	g_assert_true (GCK_IS_SESSION (new_session));
 	g_object_unref (result);
 
 	result = NULL;
 	gck_session_create_object_async (new_session, attrs, NULL, fetch_async_result, &result);
 	egg_test_wait_until (500);
-	g_assert (result != NULL);
+	g_assert_nonnull (result);
 	object = gck_session_create_object_finish (new_session, result, &err);
 	g_assert_no_error (err);
-	g_assert (GCK_IS_OBJECT (object));
+	g_assert_true (GCK_IS_OBJECT (object));
 	g_object_unref (result);
 	g_object_unref (object);
 
 	/* We should now be logged in, try to log out */
 	ret = gck_session_logout (new_session, NULL, &err);
 	g_assert_no_error (err);
-	g_assert (ret);
+	g_assert_true (ret);
 
 	gck_attributes_unref (attrs);
 	g_object_unref (new_session);
