@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@collabora.co.uk>
  */
@@ -54,11 +52,13 @@
 #include <gcr/gcr-secure-memory.h>
 #include <gcr/gcr-simple-certificate.h>
 #include <gcr/gcr-simple-collection.h>
+#include <gcr/gcr-ssh-askpass.h>
 #include <gcr/gcr-system-prompt.h>
 #include <gcr/gcr-system-prompter.h>
 #include <gcr/gcr-trust.h>
 #include <gcr/gcr-union-collection.h>
 #include <gcr/gcr-unlock-options.h>
+#include <gcr/gcr-version.h>
 
 #undef __GCR_INSIDE_HEADER__
 
