@@ -28,17 +28,10 @@
 
 G_BEGIN_DECLS
 
-#define GCR_TYPE_CALLBACK_OUTPUT_STREAM               (_gcr_callback_output_stream_get_type ())
-#define GCR_CALLBACK_OUTPUT_STREAM(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCR_TYPE_CALLBACK_OUTPUT_STREAM, GcrCallbackOutputStream))
-#define GCR_CALLBACK_OUTPUT_STREAM_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GCR_TYPE_CALLBACK_OUTPUT_STREAM, GcrCallbackOutputStreamClass))
-#define GCR_IS_CALLBACK_OUTPUT_STREAM(obj)            (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCR_TYPE_CALLBACK_OUTPUT_STREAM))
-#define GCR_IS_CALLBACK_OUTPUT_STREAM_CLASS(klass)    (G_TYPE_CHECK_CLASS_TYPE ((klass), GCR_TYPE_CALLBACK_OUTPUT_STREAM))
-#define GCR_CALLBACK_OUTPUT_STREAM_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GCR_TYPE_CALLBACK_OUTPUT_STREAM, GcrCallbackOutputStreamClass))
-
-typedef struct _GcrCallbackOutputStream GcrCallbackOutputStream;
-typedef struct _GcrCallbackOutputStreamClass GcrCallbackOutputStreamClass;
-
-GType               _gcr_callback_output_stream_get_type   (void);
+#define GCR_TYPE_CALLBACK_OUTPUT_STREAM (_gcr_callback_output_stream_get_type ())
+G_DECLARE_FINAL_TYPE (GcrCallbackOutputStream, _gcr_callback_output_stream,
+                      GCR, CALLBACK_OUTPUT_STREAM,
+                      GOutputStream)
 
 typedef gssize      (*GcrCallbackOutputFunc)               (gconstpointer buffer,
                                                             gsize count,
