@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@collabora.co.uk>
  */
@@ -108,6 +106,8 @@ gchar *             gcr_secret_exchange_send            (GcrSecretExchange *self
 const gchar *       gcr_secret_exchange_get_secret      (GcrSecretExchange *self,
                                                          gsize *secret_len);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (GcrSecretExchange, g_object_unref)
+
 G_END_DECLS
 
 #endif /* __GCR_SECRET_EXCHANGE_H__ */
