@@ -28,17 +28,10 @@
 
 G_BEGIN_DECLS
 
-#define GCR_TYPE_SINGLE_COLLECTION               (_gcr_single_collection_get_type ())
-#define GCR_SINGLE_COLLECTION(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GCR_TYPE_COLLECTION, GcrSingleCollection))
-#define GCR_SINGLE_COLLECTION_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GCR_TYPE_COLLECTION, GcrSingleCollectionClass))
-#define GCR_IS_SINGLE_COLLECTION(obj)            (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GCR_TYPE_COLLECTION))
-#define GCR_IS_SINGLE_COLLECTION_CLASS(klass)    (G_TYPE_CHECK_CLASS_TYPE ((klass), GCR_TYPE_COLLECTION))
-#define GCR_SINGLE_COLLECTION_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GCR_TYPE_COLLECTION, GcrSingleCollectionClass))
-
-typedef struct _GcrSingleCollection GcrSingleCollection;
-typedef struct _GcrSingleCollectionClass GcrSingleCollectionClass;
-
-GType               _gcr_single_collection_get_type                (void);
+#define GCR_TYPE_SINGLE_COLLECTION (_gcr_single_collection_get_type ())
+G_DECLARE_FINAL_TYPE (GcrSingleCollection, _gcr_single_collection,
+                      GCR, SINGLE_COLLECTION,
+                      GObject)
 
 GcrCollection *     _gcr_single_collection_new                     (GObject *object);
 
