@@ -35,7 +35,7 @@ struct _GcrViewerWindowPrivate {
 	GcrImportButton *import;
 };
 
-G_DEFINE_TYPE (GcrViewerWindow, gcr_viewer_window, GTK_TYPE_WINDOW);
+G_DEFINE_TYPE_WITH_PRIVATE (GcrViewerWindow, gcr_viewer_window, GTK_TYPE_WINDOW);
 
 static void
 on_viewer_renderer_added (GcrViewerWidget *viewer,
@@ -50,8 +50,7 @@ on_viewer_renderer_added (GcrViewerWidget *viewer,
 static void
 gcr_viewer_window_init (GcrViewerWindow *self)
 {
-	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, GCR_TYPE_VIEWER_WINDOW,
-	                                        GcrViewerWindowPrivate);
+	self->pv = gcr_viewer_window_get_instance_private (self);
 }
 
 static void
@@ -95,7 +94,6 @@ gcr_viewer_window_constructed (GObject *obj)
 	GtkWidget *bbox;
 	GtkWidget *box;
 	GtkWidget *button;
-	GtkWidget *align;
 
 	G_OBJECT_CLASS (gcr_viewer_window_parent_class)->constructed (obj);
 
@@ -122,10 +120,13 @@ gcr_viewer_window_constructed (GObject *obj)
 	gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (bbox), GTK_WIDGET (self->pv->import), FALSE, TRUE, 0);
 
-	align = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 0, 12);
-	gtk_widget_show (align);
-	gtk_container_add (GTK_CONTAINER (align), bbox);
+	gtk_widget_set_halign (bbox, 0.5);
+	gtk_widget_set_valign (bbox, 0.5);
+#if GTK_CHECK_VERSION (3, 12, 0)
+	gtk_widget_set_margin_end (bbox, 12);
+#else
+	gtk_widget_set_margin_right (bbox, 12);
+#endif
 
 	self->pv->viewer = gcr_viewer_widget_new ();
 	g_object_bind_property (self->pv->viewer, "display-name",
@@ -139,7 +140,7 @@ gcr_viewer_window_constructed (GObject *obj)
 	gtk_widget_show (box);
 
 	gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (self->pv->viewer), TRUE, TRUE, 0);
-	gtk_box_pack_start (GTK_BOX (box), align, FALSE, FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (box), bbox, FALSE, FALSE, 6);
 
 	gtk_container_add (GTK_CONTAINER (self), box);
 
@@ -152,8 +153,6 @@ gcr_viewer_window_class_init (GcrViewerWindowClass *klass)
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
 	gobject_class->constructed = gcr_viewer_window_constructed;
-
-	g_type_class_add_private (klass, sizeof (GcrViewerWindow));
 }
 
 /**
